pilas.actores.caja

Package pilas :: Package actores :: Module caja |
[hide private]
[frames] | no frames]

# Source Code for Module pilas.actores.caja

     1  # -*- encoding: utf-8 -*-
     2  # Pilas engine - A video game framework.
     3  #
     4  # Copyright 2010 - Hugo Ruscitti
     5  # License: LGPLv3 (see http://www.gnu.org/licenses/lgpl.html)
     6  #
     7  # Website - http://www.pilas-engine.com.ar
     8
     9  from pilas.actores import Actor
    10  import pilas
    11
    12
    13 -class Caja(Actor):
    14      """Representa una caja que posee fisica.
    15
    16      .. image:: images/actores/caja.png
    17
    18      """
    19
    20 -    def __init__(self, x=0, y=0):
    21          """ Constructor de la Caja.
    22
    23          :param x: Posición horizontal de la Caja.
    24          :type x: int
    25          :param y: Posición vertical del Caja.
    26          :type y: int
    27          """
    28          imagen = pilas.imagenes.cargar('caja.png')
    29          Actor.__init__(self, imagen)
    30          self.rotacion = 0
    31          self.x = x
    32          self.y = y
    33          self.radio_de_colision = 25
    34
    35          self.aprender(pilas.habilidades.RebotarComoCaja)
    36